@@ -1,4 +1,4 @@
-from .Graph import Graph, draw_graph
+from ._GraphForDisplay import Graph
 from .Node import Node
 from .Edge import Edge
 from .get_ancestors import get_ancestors
